@@ -1,12 +1,8 @@
-use crate::ActivateProposal;
+use crate::{electorate_seeds, ActivateProposal};
 use anchor_lang::prelude::*;
 
 pub fn activate_proposal(ctx: Context<ActivateProposal>) -> ProgramResult {
-    let seeds: &[&[&[u8]]] = &[&[
-        b"SimpleElectorate".as_ref(),
-        &ctx.accounts.electorate.base.to_bytes(),
-        &[ctx.accounts.electorate.bump],
-    ]];
+    let seeds: &[&[&[u8]]] = electorate_seeds!(ctx.accounts.electorate);
     govern::cpi::activate_proposal(
         CpiContext::new(
             ctx.accounts.govern_program.to_account_info(),
